@@ -324,16 +324,16 @@ class postgres(threading.Thread, SQLProvider):
             self._prepared = stmt
         except RuntimeError as err:
             error = "Runtime on Query Row Error: {}".format(str(err))
-            raise ProviderError(error)
+            raise ProviderError(message=error)
         except (PostgresSyntaxError, UndefinedColumnError, PostgresError) as err:
             error = "Sentence on Query Row Error: {}".format(str(err))
-            raise StatementError(error)
+            raise StatementError(message=error)
         except (
             asyncpg.exceptions.InvalidSQLStatementNameError,
             asyncpg.exceptions.UndefinedTableError,
         ) as err:
             error = "Invalid Statement Error: {}".format(str(err))
-            raise StatementError(error)
+            raise StatementError(message=error)
         except Exception as err:
             error = "Error on Query Row: {}".format(str(err))
             raise Exception(error)
@@ -349,16 +349,16 @@ class postgres(threading.Thread, SQLProvider):
             self._columns = [a.name for a in stmt.get_attributes()]
         except RuntimeError as err:
             error = "Runtime on Query Row Error: {}".format(str(err))
-            raise ProviderError(error)
+            raise ProviderError(message=error)
         except (PostgresSyntaxError, UndefinedColumnError, PostgresError) as err:
             error = "Sentence on Query Row Error: {}".format(str(err))
-            raise StatementError(error)
+            raise StatementError(message=error)
         except (
             asyncpg.exceptions.InvalidSQLStatementNameError,
             asyncpg.exceptions.UndefinedTableError,
         ) as err:
             error = "Invalid Statement Error: {}".format(str(err))
-            raise StatementError(error)
+            raise StatementError(message=error)
         except Exception as err:
             error = "Error on Query Row: {}".format(str(err))
             raise Exception(error)
@@ -381,16 +381,16 @@ class postgres(threading.Thread, SQLProvider):
                 return [None, "Data was not found"]
         except RuntimeError as err:
             error = "Runtime Error: {}".format(str(err))
-            raise ProviderError(error)
+            raise ProviderError(message=error)
         except (PostgresSyntaxError, UndefinedColumnError, PostgresError) as err:
             error = "Sentence Error: {}".format(str(err))
-            raise StatementError(error)
+            raise StatementError(message=error)
         except (
             asyncpg.exceptions.InvalidSQLStatementNameError,
             asyncpg.exceptions.UndefinedTableError,
         ) as err:
             error = "Invalid Statement Error: {}".format(str(err))
-            raise StatementError(error)
+            raise StatementError(message=error)
         except Exception as err:
             error = "Error on Query: {}".format(str(err))
             raise Exception(error)
@@ -414,16 +414,16 @@ class postgres(threading.Thread, SQLProvider):
             self._result = await stmt.fetchrow()
         except RuntimeError as err:
             error = "Runtime on Query Row Error: {}".format(str(err))
-            raise ProviderError(error)
+            raise ProviderError(message=error)
         except (PostgresSyntaxError, UndefinedColumnError, PostgresError) as err:
             error = "Sentence on Query Row Error: {}".format(str(err))
-            raise StatementError(error)
+            raise StatementError(message=error)
         except (
             asyncpg.exceptions.InvalidSQLStatementNameError,
             asyncpg.exceptions.UndefinedTableError,
         ) as err:
             error = "Invalid Statement Error: {}".format(str(err))
-            raise StatementError(error)
+            raise StatementError(message=error)
         except Exception as err:
             error = "Error on Query Row: {}".format(str(err))
             raise Exception(error)
@@ -449,7 +449,7 @@ class postgres(threading.Thread, SQLProvider):
             return [self._result, None]
         except InterfaceWarning as err:
             self._error = "Interface Warning: {}".format(str(err))
-            raise ProviderError(error)
+            raise ProviderError(message=error)
         except Exception as err:
             self._error = "Error on Execute: {}".format(str(err))
         finally:
@@ -474,7 +474,7 @@ class postgres(threading.Thread, SQLProvider):
             return [True, None]
         except InterfaceWarning as err:
             self._error = "Interface Warning: {}".format(str(err))
-            raise ProviderError(error)
+            raise ProviderError(message=error)
         except Exception as err:
             self._error = "Error on Execute: {}".format(str(err))
         finally:
@@ -600,16 +600,16 @@ class postgres(threading.Thread, SQLProvider):
                     result=result, columns=self._columns)
         except RuntimeError as err:
             self._error = "Runtime Error: {}".format(str(err))
-            raise ProviderError(error)
+            raise ProviderError(message=error)
         except (PostgresSyntaxError, UndefinedColumnError, PostgresError) as err:
             self._error = "Sentence Error: {}".format(str(err))
-            raise StatementError(error)
+            raise StatementError(message=error)
         except (
             asyncpg.exceptions.InvalidSQLStatementNameError,
             asyncpg.exceptions.UndefinedTableError,
         ) as err:
             self._error = "Invalid Statement Error: {}".format(str(err))
-            raise StatementError(error)
+            raise StatementError(message=error)
         except Exception as err:
             self._error = "Error on Query: {}".format(str(err))
             raise Exception(error)
