@@ -1,5 +1,13 @@
 from .encoders import DefaultEncoder, EnumEncoder, BaseEncoder
-from .functions import colors, SafeDict, is_pgconstant, is_udf, _escapeString, Msg
+from .functions import (
+    colors,
+    Msg,
+    SafeDict,
+    is_pgconstant,
+    is_udf,
+    _escapeString,
+    module_exists
+)
 
 __all__ = [
     "colors",
@@ -11,4 +19,5 @@ __all__ = [
     "is_udf",
     "_escapeString",
     "Msg",
+    "module_exists",
 ]
